@@ -2,9 +2,11 @@
 propagate.grain <- function(object, details=object$details, ...){
 
   t0 <- proc.time()
-  object$potlist <- propagateLS(object$potlistwork,
+  ## propagate.grain: equilCQpot is updated after propagation on tempCQpot
+  ## such that equilCQpot will contain the updated potentials. 
+  object$equilCQpot <- propagateLS(object$tempCQpot,
                                 rip=object$rip, initialize=TRUE, details=details)
-
+  
   object$isInitialized <- TRUE
   object$isPropagated  <- TRUE
   
@@ -12,7 +14,7 @@ propagate.grain <- function(object, details=object$details, ...){
     ev <- getFinding(object)
     attr(ev,"pFinding")<- pFinding(object)
     object$finding <- ev    
-  }
+  }     
   if (object$control$timing){
     cat("Time: propagation", proc.time()-t0, "\n")
   }
@@ -21,7 +23,8 @@ propagate.grain <- function(object, details=object$details, ...){
 
 ## Lauritzen Spiegelhalter propagation
 ##
-propagateLS <- function(potlist, rip, initialize=TRUE, details=0){
+
+propagateLS <- function(APlist, rip, initialize=TRUE, details=0){
 
   .infoPrint(details, 1, cat(".Propagating BN: [propagateLS]\n"))
 
@@ -41,34 +44,34 @@ propagateLS <- function(potlist, rip, initialize=TRUE, details=0){
   if (ncliq>1){
     for (ii in ncliq:2){      
       .infoPrint2(details, 2, "Clique %d: {%s}\n", ii, .colstr(cliq[[ii]]))
-      cpot  <- potlist[[ii]];      
+      cpot  <- APlist[[ii]];      
       csep  <- seps[[ii]]
-      cpa   <- potlist[[pa[ii]]]
+      cpa   <- APlist[[pa[ii]]]
       if (length(csep)>=1 && !is.na(csep)){
         .infoPrint2(details, 2, "Marg onto sep {%s}\n", .colstr(csep))        
         septab            <- tableMargin(cpot, csep)
-        potlist[[ii]]     <- tableOp2(cpot, septab, `/`)             
-        potlist[[pa[ii]]] <- tableOp2(cpa,  septab, `*`) 
+        APlist[[ii]]     <- tableOp2(cpot, septab, `/`)             
+        APlist[[pa[ii]]] <- tableOp2(cpa,  septab, `*`) 
       } else{
         zzz <- sum(cpot)
-        potlist[[1]]  <- potlist[[1]] * zzz
-        potlist[[ii]] <- cpot / zzz
+        APlist[[1]]  <- APlist[[1]] * zzz
+        APlist[[ii]] <- cpot / zzz
       }
     }
   }
   
 ##   cat("propagateLS\n")
-##   print(as.data.frame.table(potlist[[1]]))
+##   print(as.data.frame.table(APlist[[1]]))
   
-  normConst <- sum(potlist[[1]]) 
-##   print(normConst)
+  normConst <- sum(APlist[[1]]) 
+  #print(normConst)
   
   if (normConst==0){
-    attr(potlist, "pFinding") <- normConst
+    attr(APlist, "pFinding") <- normConst
   }
 
   if (initialize){
-    potlist[[1]] <- potlist[[1]]/normConst 
+    APlist[[1]] <- APlist[[1]]/normConst 
   }
   
   ## Forward propagation (distribute evidence) away from root of junction tree
@@ -85,14 +88,14 @@ propagateLS <- function(potlist, rip, initialize=TRUE, details=0){
       for (jj in 1:length(ch)){
         if (length(seps[[ch[jj]]])>0){
           .infoPrint2(details, 2, "Marg onto sep %i: {%s}\n", ch[jj], .colstr(seps[[ch[jj]]]))
-          septab            <- tableMargin(potlist[[ii]], seps[[ch[jj]]])
-          potlist[[ch[jj]]] <- tableOp2(potlist[[ch[jj]]], septab, `*`) 
+          septab            <- tableMargin(APlist[[ii]], seps[[ch[jj]]])
+          APlist[[ch[jj]]] <- tableOp2(APlist[[ch[jj]]], septab, `*`) 
           .infoPrint(details, 4, { cat("Marginal:\n"); print (septab) })          
         }
       }
     }
   }
 
-  attr(potlist, "pFinding") <- normConst
-  potlist
+  attr(APlist, "pFinding") <- normConst
+  APlist
 }
